@@ -50,6 +50,7 @@ class TestJoinedLoading(TestCase):
         )
         self.session.add(article)
         self.session.commit()
+        self.session.expunge_all()
 
     def test_joinedload_for_current_translation(self):
         article = (
@@ -78,3 +79,22 @@ class TestJoinedLoading(TestCase):
         query_count = self.connection.query_count
         article.name
         assert query_count == self.connection.query_count
+
+    def test_joinedload_for_attr_accessor(self):
+        article = (
+            self.session.query(self.Article)
+            .options(sa.orm.joinedload(self.Article.translations.en))
+        ).first()
+        query_count = self.connection.query_count
+        article.name
+        assert query_count == self.connection.query_count
+
+    def test_joinedload_for_all_translations(self):
+        article = (
+            self.session.query(self.Article)
+            .options(sa.orm.joinedload(self.Article.translations))
+        ).first()
+        query_count = self.connection.query_count
+        article.name
+        article.translations['fi'].name
+        assert query_count == self.connection.query_count
